@@ -4,14 +4,16 @@ use strict;
 use warnings;
 use utf8;
 
+use Test::BDD::Cucumber::Definitions::File::Ru;
 use Test::BDD::Cucumber::Definitions::HTTP::Ru;
 use Test::BDD::Cucumber::Definitions::Struct::Ru;
 use Test::BDD::Cucumber::Definitions::Var::Ru;
 use Test::BDD::Cucumber::Definitions::Zip::Ru;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 sub import {
+    Test::BDD::Cucumber::Definitions::File::Ru->import;
     Test::BDD::Cucumber::Definitions::HTTP::Ru->import;
     Test::BDD::Cucumber::Definitions::Struct::Ru->import;
     Test::BDD::Cucumber::Definitions::Var::Ru->import;
